@@ -31,8 +31,23 @@ import os
 import uuid
 from optparse import OptionParser
 
-from . import base, constants, exceptions, interfaces, nsclient
-from . import utils, zerojson
+import zerojson
+
+from . import base, constants, interfaces, nsclient, utils
+
+
+class PyComServer(zerojson.Server):
+    """ZeroJSON server with PyCOM calling."""
+
+    def handle_call(self, request):
+        """Handle a single call."""
+        try:
+            service = interfaces.registry[request.interface]
+        except KeyError:
+            raise zerojson.BadRequest(
+                "Unsupported interface: %s" % request.interface)
+
+        return service.__interface__.invoke_with_request(request)
 
 
 def main(argv=None, client_context=None):
@@ -91,9 +106,11 @@ def main(argv=None, client_context=None):
 
         utils.logger().setLevel(options.verbosity or
             int(os.environ.get("PYCOM_LOGGING_LEVEL", 0)) or logging.INFO)
+        zerojson.utils.logger().setLevel(options.verbosity or
+            int(os.environ.get("PYCOM_LOGGING_LEVEL", 0)) or logging.INFO)
 
     if address is None:
-        raise exceptions.ConfigurationError("Set address in the configuration")
+        raise base.ConfigurationError("Set address in the configuration")
 
     if service is None:
         service = "/auto/" + uuid.uuid4().hex
@@ -107,7 +124,7 @@ def main(argv=None, client_context=None):
 
     _register()
 
-    zerojson.setup_ioloop(address)
+    PyComServer([address]).setup()
 
     utils.logger().info("PyCOM v%s (service '%s' on '%s')",
         constants.__version__, service, address)
