@@ -27,6 +27,7 @@
 """Synchronous client API for PyCOM nameserver."""
 
 import copy
+import threading
 
 import zerojson
 
@@ -58,13 +59,15 @@ class Context(object):
               Data to be processed (:class:`zerojson.Request` for prehooks,
               :class:`zerojson.Response` for posthooks).
 
+    Context are thread-safe, unlike components they provide.
+
     """
 
     def __init__(self, nameserver=None):
         """Constructor."""
         self.prehooks = []
         self.posthooks = []
-        self._ns_component = None
+        self._ns_tls = threading.local()
         self._ns_hint = nameserver
 
     def nameserver(self):
@@ -119,6 +122,18 @@ class Context(object):
         """Connect to a service providing *iface* on a given *address*."""
         return RemoteComponent(address, iface, context=self)
 
+    # Private
+
+    @property
+    def _ns_component(self):
+        """Returns NS component for current thread or None."""
+        return getattr(self._ns_tls, "cached", None)
+
+    @_ns_component.setter
+    def _ns_component(self, value):
+        """Set new cached component."""
+        self._ns_tls.cached = value
+
 
 # Protected
 
