@@ -466,7 +466,7 @@ class IntrospectionTest(BaseTest, unittest.TestCase):
                     constants.GENERIC_METHOD_INTROSPECT: {
                         "required_arguments": [],
                         "optional_arguments": [],
-                        "results": ["name", "methods", "docstring"],
+                        "results": ["name", "methods", "docstring", "data"],
                         "docstring":
                             "Provides introspection information for a service."
                     },
@@ -483,7 +483,8 @@ class IntrospectionTest(BaseTest, unittest.TestCase):
                         "docstring": None
                     }
                 },
-                "docstring": "My Demo Service"
+                "docstring": "My Demo Service",
+                "data": {}
         })
 
     def testViaMethod(self):
@@ -505,28 +506,32 @@ class IntrospectionTest(BaseTest, unittest.TestCase):
 
         component = InterfaceWithMethods.__interface__
         self.assertEqual(
-            component.introspect(), {
-                "name": iface,
-                "methods": {
-                    constants.GENERIC_METHOD_INTROSPECT: {
-                        "required_arguments": [],
-                        "optional_arguments": [],
-                        "results": ["name", "methods", "docstring"],
-                        "docstring":
-                            "Provides introspection information for a service."
-                    },
-                    meth1: {
-                        "required_arguments": ["arg1"],
-                        "optional_arguments": ["arg2", "arg3"],
-                        "results": [],
-                        "docstring": "My Demo Method"
-                    },
-                    meth2: {
-                        "required_arguments": [],
-                        "optional_arguments": [],
-                        "results": ["res1", "res2"],
-                        "docstring": None
-                    }
-                },
-                "docstring": "My Demo Service"
-        })
+            component.introspect(),
+            component.invoke(constants.GENERIC_METHOD_INTROSPECT))
+
+    def testIntrospectionData(self):
+        iface = "test.test_interfaces.IntrospectionTest.testIntrospectionData"
+
+        @pycom.interface(iface)
+        class InterfaceWithMethods(pycom.Service):
+
+            introspection_data = {
+                "x": None
+            }
+
+        component = InterfaceWithMethods.__interface__
+        self.assertEqual(
+            component.invoke(constants.GENERIC_METHOD_INTROSPECT)["data"], {
+                "x": None
+            })
+
+    def testWrongIntrospectionData(self):
+        iface = "test.test_interfaces.IntrospectionTest.testIntrospectionData"
+
+        def _check():
+            @pycom.interface(iface)
+            class InterfaceWithMethods(pycom.Service):
+
+                introspection_data = 42
+
+        self.assertRaises(TypeError, _check)
