@@ -26,17 +26,15 @@
 
 """Auxiliary utils."""
 
-import logging
 import os
 import sys
-import uuid
+
+import zerojson
 
 from . import __file__ as pycom_file
 
 
-def logger():
-    """Returns current logger for PyCOM."""
-    return logging.getLogger("pycom")
+logger = zerojson.create_logger("PyCOM")  #: Default logger for PyCOM
 
 
 def find_conf_file(basename):
@@ -52,43 +50,3 @@ def find_conf_file(basename):
         return conf_file
     else:
         return None
-
-
-class UUIDFactory(object):
-    """Factory responsible for creating objects with UUID."""
-
-    def __init__(self, items_factory):
-        """Initialize empty factory."""
-        self._items = {}
-        self._items_factory = items_factory
-
-    def new(self):
-        """Create new session object and return it."""
-        unique_id = uuid.uuid1().hex
-        self._items[unique_id] = self._items_factory(unique_id,
-            session_factory=self)
-        return self.get(unique_id)  # Allow for overloading
-
-    def get(self, unique_id):
-        """Fetch existing item by it's ID.
-
-        Raises `KeyError` on failure.
-
-        """
-        return self._items[unique_id]
-
-    def drop(self, unique_id):
-        """Drop existing item by it's ID."""
-        del self._items[unique_id]
-
-
-# Initialize logger
-
-
-_logging_formatter = logging.Formatter(
-    fmt="PyCOM %(levelname)s %(asctime)s: %(message)s")
-_logging_handler = logging.StreamHandler()
-_logging_handler.setFormatter(_logging_formatter)
-
-logger().addHandler(_logging_handler)
-logger().propagate = False
